;; Generated package description from persist.el  -*- no-byte-compile: t -*-
(define-package "persist" "0.3" "Persist Variables" 'nil :url "http://elpa.gnu.org/packages/persist.html" :authors '(("Phillip Lord" . "phillip.lord@russet.org.uk")) :maintainer '("Phillip Lord" . "phillip.lord@russet.org.uk"))
